@@ -59,8 +59,10 @@ def get_nat_regdirs(verbose=False):
 
     # Parse output
     outstr = proc.stdout.decode()
-    path = pathlib.Path(re.search('.*?"(.*?)"', outstr).group(1))
-    regdirs.append(path)
+    match = re.search('.*?"(.*?)"', outstr)
+    if match and match.group(1).strip() != '':
+        path = pathlib.Path(match.group(1))
+        regdirs.append(path)
 
     # This is basepath for nat.flybrains
     cmd = "regdirs=c('bridgingregistrations', 'mirroringregistrations');system.file('extdata', regdirs, package = 'nat.flybrains')"
@@ -76,6 +78,12 @@ def get_nat_regdirs(verbose=False):
             continue
         match = re.search('.*?"(.*?)"', line)
         if match:
+            # Skip empty strings (happens if path not set at all)
+            # If we don't skip then we add the current directory
+            # `PosixPath('.')` which will lead to A LOT of recursive
+            # searching
+            if match.group(1).strip() == '':
+                continue
             path = pathlib.Path(match.group(1))
             regdirs.append(path)
 
@@ -88,8 +96,10 @@ def get_nat_regdirs(verbose=False):
 
     # Parse output
     outstr = proc.stdout.decode()
-    path = pathlib.Path(re.search('.*?"(.*?)"', outstr).group(1))
-    regdirs.append(path)
+    match = re.search('.*?"(.*?)"', outstr)
+    if match and match.group(1).strip() != '':
+        path = pathlib.Path(match.group(1))
+        regdirs.append(path)
 
     return regdirs
 
@@ -248,6 +258,27 @@ def register_transforms():
                                            target='FAFB14',
                                            transform_type='bridging')
 
+    # Add alias transform between JRCFIB2018F and hemibrain (they are synonymous)
+    tr = transforms.base.AliasTransform()
+    transforms.registry.register_transform(transform=tr,
+                                           source='hemibrain',
+                                           target='JRCFIB2018F',
+                                           transform_type='bridging')
+
+    # Add alias transform between JRCFIB2018F and hemibrain (they are synonymous)
+    tr = transforms.base.AliasTransform()
+    transforms.registry.register_transform(transform=tr,
+                                           source='hemibrainraw',
+                                           target='JRCFIB2018Fraw',
+                                           transform_type='bridging')
+
+    # Add alias transform between JRCFIB2018F and hemibrain (they are synonymous)
+    tr = transforms.base.AliasTransform()
+    transforms.registry.register_transform(transform=tr,
+                                           source='hemibrainum',
+                                           target='JRCFIB2018Fum',
+                                           transform_type='bridging')
+
     # Add alias transform between FAFB and FAFB14 (they are synonymous)
     tr = transforms.base.AliasTransform()
     transforms.registry.register_transform(transform=tr,
